@@ -51,6 +51,7 @@ sub run {
     "r|remote=s"  => \$config{remote},
     "d|dirmode=s" => \$config{dirmode},
     "qq"          => sub { $config{quiet} = 2; $config{errors} = 0; },
+    'offline'     => \$config{offline},
     "q+" => \$config{quiet},
     "f+" => \$config{force},
     "p+" => \$config{perl},
@@ -72,6 +73,7 @@ sub run {
     trace   => (not $config{quiet}),
     force   => $config{force},
     dirmode => $config{dirmode},
+    offline => $config{offline},
     also_mirror    => $config{also_mirror},
     exact_mirror   => ($config{exact_mirror}),
     module_filters => ($config{module_filters}),
